@@ -1,5 +1,5 @@
 /*
- * Copyright © 2008 Red Hat, Inc.
+ * Copyright © 2008-2012 Red Hat, Inc.
  *
  * Permission to use, copy, modify, distribute, and sell this software
  * and its documentation for any purpose is hereby granted without
@@ -35,7 +35,6 @@
 #include <xf86Xinput.h>
 #include <exevents.h>
 
-#include "synaptics.h"
 #include "synapticsstr.h"
 #include "synaptics-properties.h"
 
@@ -59,7 +58,6 @@ Atom prop_tap_time = 0;
 Atom prop_tap_move = 0;
 Atom prop_tap_durations = 0;
 Atom prop_clickpad = 0;
-Atom prop_tap_fast = 0;
 Atom prop_middle_timeout = 0;
 Atom prop_twofinger_pressure = 0;
 Atom prop_twofinger_width = 0;
@@ -70,9 +68,6 @@ Atom prop_speed = 0;
 Atom prop_edgemotion_pressure = 0;
 Atom prop_edgemotion_speed = 0;
 Atom prop_edgemotion_always = 0;
-Atom prop_buttonscroll = 0;
-Atom prop_buttonscroll_repeat = 0;
-Atom prop_buttonscroll_time = 0;
 Atom prop_off = 0;
 Atom prop_lockdrags = 0;
 Atom prop_lockdrags_time = 0;
@@ -205,7 +200,7 @@ InitDeviceProperties(InputInfoPtr pInfo)
 
     values[0] = para->finger_low;
     values[1] = para->finger_high;
-    values[2] = para->finger_press;
+    values[2] = 0;
 
     prop_finger = InitAtom(pInfo->dev, SYNAPTICS_PROP_FINGER, 32, 3, values);
     prop_tap_time =
@@ -221,8 +216,6 @@ InitDeviceProperties(InputInfoPtr pInfo)
         InitAtom(pInfo->dev, SYNAPTICS_PROP_TAP_DURATIONS, 32, 3, values);
     prop_clickpad =
         InitAtom(pInfo->dev, SYNAPTICS_PROP_CLICKPAD, 8, 1, &para->clickpad);
-    prop_tap_fast =
-        InitAtom(pInfo->dev, SYNAPTICS_PROP_TAP_FAST, 8, 1, &para->fast_taps);
     prop_middle_timeout =
         InitAtom(pInfo->dev, SYNAPTICS_PROP_MIDDLE_TIMEOUT, 32, 1,
                  &para->emulate_mid_button_time);
@@ -251,38 +244,9 @@ InitDeviceProperties(InputInfoPtr pInfo)
     fvalues[0] = para->min_speed;
     fvalues[1] = para->max_speed;
     fvalues[2] = para->accl;
-    fvalues[3] = para->trackstick_speed;
+    fvalues[3] = 0;
     prop_speed = InitFloatAtom(pInfo->dev, SYNAPTICS_PROP_SPEED, 4, fvalues);
 
-    values[0] = para->edge_motion_min_z;
-    values[1] = para->edge_motion_max_z;
-    prop_edgemotion_pressure =
-        InitAtom(pInfo->dev, SYNAPTICS_PROP_EDGEMOTION_PRESSURE, 32, 2, values);
-
-    values[0] = para->edge_motion_min_speed;
-    values[1] = para->edge_motion_max_speed;
-    prop_edgemotion_speed =
-        InitAtom(pInfo->dev, SYNAPTICS_PROP_EDGEMOTION_SPEED, 32, 2, values);
-    prop_edgemotion_always =
-        InitAtom(pInfo->dev, SYNAPTICS_PROP_EDGEMOTION, 8, 1,
-                 &para->edge_motion_use_always);
-
-    if (priv->has_scrollbuttons) {
-        values[0] = para->updown_button_scrolling;
-        values[1] = para->leftright_button_scrolling;
-        prop_buttonscroll =
-            InitAtom(pInfo->dev, SYNAPTICS_PROP_BUTTONSCROLLING, 8, 2, values);
-
-        values[0] = para->updown_button_repeat;
-        values[1] = para->leftright_button_repeat;
-        prop_buttonscroll_repeat =
-            InitAtom(pInfo->dev, SYNAPTICS_PROP_BUTTONSCROLLING_REPEAT, 8, 2,
-                     values);
-        prop_buttonscroll_time =
-            InitAtom(pInfo->dev, SYNAPTICS_PROP_BUTTONSCROLLING_TIME, 32, 1,
-                     &para->scroll_button_repeat);
-    }
-
     prop_off =
         InitAtom(pInfo->dev, SYNAPTICS_PROP_OFF, 8, 1, &para->touchpad_off);
     prop_lockdrags =
@@ -312,9 +276,6 @@ InitDeviceProperties(InputInfoPtr pInfo)
     prop_circscroll_trigger =
         InitAtom(pInfo->dev, SYNAPTICS_PROP_CIRCULAR_SCROLLING_TRIGGER, 8, 1,
                  &para->circular_trigger);
-    prop_circpad =
-        InitAtom(pInfo->dev, SYNAPTICS_PROP_CIRCULAR_PAD, 8, 1,
-                 &para->circular_pad);
     prop_palm =
         InitAtom(pInfo->dev, SYNAPTICS_PROP_PALM_DETECT, 8, 1,
                  &para->palm_detect);
@@ -443,8 +404,6 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
 
         para->finger_low = finger[0];
         para->finger_high = finger[1];
-        para->finger_press = finger[2];
-
     }
     else if (property == prop_tap_time) {
         if (prop->size != 1 || prop->format != 32 || prop->type != XA_INTEGER)
@@ -487,13 +446,6 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
 
         para->clickpad = *(BOOL *) prop->data;
     }
-    else if (property == prop_tap_fast) {
-        if (prop->size != 1 || prop->format != 8 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        para->fast_taps = *(BOOL *) prop->data;
-
-    }
     else if (property == prop_middle_timeout) {
         if (prop->size != 1 || prop->format != 32 || prop->type != XA_INTEGER)
             return BadMatch;
@@ -524,18 +476,14 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
 
         if (para->scroll_dist_vert != dist[0]) {
             para->scroll_dist_vert = dist[0];
-#ifdef HAVE_SMOOTH_SCROLL
             SetScrollValuator(dev, priv->scroll_axis_vert, SCROLL_TYPE_VERTICAL,
                               para->scroll_dist_vert, 0);
-#endif
         }
         if (para->scroll_dist_horiz != dist[1]) {
             para->scroll_dist_horiz = dist[1];
-#ifdef HAVE_SMOOTH_SCROLL
             SetScrollValuator(dev, priv->scroll_axis_horiz,
                               SCROLL_TYPE_HORIZONTAL, para->scroll_dist_horiz,
                               0);
-#endif
         }
     }
     else if (property == prop_scrolledge) {
@@ -569,80 +517,6 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
         para->min_speed = speed[0];
         para->max_speed = speed[1];
         para->accl = speed[2];
-        para->trackstick_speed = speed[3];
-
-    }
-    else if (property == prop_edgemotion_pressure) {
-        CARD32 *pressure;
-
-        if (prop->size != 2 || prop->format != 32 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        pressure = (CARD32 *) prop->data;
-        if (pressure[0] > pressure[1])
-            return BadValue;
-
-        para->edge_motion_min_z = pressure[0];
-        para->edge_motion_max_z = pressure[1];
-
-    }
-    else if (property == prop_edgemotion_speed) {
-        CARD32 *speed;
-
-        if (prop->size != 2 || prop->format != 32 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        speed = (CARD32 *) prop->data;
-        if (speed[0] > speed[1])
-            return BadValue;
-
-        para->edge_motion_min_speed = speed[0];
-        para->edge_motion_max_speed = speed[1];
-
-    }
-    else if (property == prop_edgemotion_always) {
-        if (prop->size != 1 || prop->format != 8 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        para->edge_motion_use_always = *(BOOL *) prop->data;
-
-    }
-    else if (property == prop_buttonscroll) {
-        BOOL *scroll;
-
-        if (!priv->has_scrollbuttons)
-            return BadMatch;
-
-        if (prop->size != 2 || prop->format != 8 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        scroll = (BOOL *) prop->data;
-        para->updown_button_scrolling = scroll[0];
-        para->leftright_button_scrolling = scroll[1];
-
-    }
-    else if (property == prop_buttonscroll_repeat) {
-        BOOL *repeat;
-
-        if (!priv->has_scrollbuttons)
-            return BadMatch;
-
-        if (prop->size != 2 || prop->format != 8 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        repeat = (BOOL *) prop->data;
-        para->updown_button_repeat = repeat[0];
-        para->leftright_button_repeat = repeat[1];
-    }
-    else if (property == prop_buttonscroll_time) {
-        if (!priv->has_scrollbuttons)
-            return BadMatch;
-
-        if (prop->size != 1 || prop->format != 32 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        para->scroll_button_repeat = *(INT32 *) prop->data;
-
     }
     else if (property == prop_off) {
         CARD8 off;
@@ -736,12 +610,6 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
         para->circular_trigger = trigger;
 
     }
-    else if (property == prop_circpad) {
-        if (prop->size != 1 || prop->format != 8 || prop->type != XA_INTEGER)
-            return BadMatch;
-
-        para->circular_pad = *(BOOL *) prop->data;
-    }
     else if (property == prop_palm) {
         if (prop->size != 1 || prop->format != 8 || prop->type != XA_INTEGER)
             return BadMatch;
@@ -782,6 +650,19 @@ SetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop,
         para->press_motion_min_z = press[0];
         para->press_motion_max_z = press[1];
     }
+    else if (property == prop_pressuremotion_factor) {
+        float *press;
+
+        if (prop->size != 2 || prop->format != 32 || prop->type != float_type)
+            return BadMatch;
+
+        press = (float *) prop->data;
+        if (press[0] > press[1])
+            return BadValue;
+
+        para->press_motion_min_factor = press[0];
+        para->press_motion_max_factor = press[1];
+    }
     else if (property == prop_grab) {
         if (prop->size != 1 || prop->format != 8 || prop->type != XA_INTEGER)
             return BadMatch;
